@@ -116,6 +116,10 @@ def handle_function(tree: Tree):
         if isinstance(child, Tree) and child.data == 'identifier_def':
             name = child.children[0].value
         if isinstance(child, Tree) and child.data == 'code_block':
+            # Check for empty function body / storage vars
+            if len(child.children) == 0:
+                continue
+
             if len(child.children[0].children) > 1:
                 type_hint = child.children[0].children[1].value
                 inputs += get_function_parameters(type_hint, function_inputs_pattern)
